Rom

Struct Rom 

pub struct Rom<T: Deref<Target = [u8]>> { /* private fields */ }

Implementations

Source

impl<T: Deref<Target = [u8]>> Rom<T>

pub fn load(storage: T) -> Result<Self, Error>

Build a rom from a sequence of storage

pub fn header(&self) -> &[u8]

Shortcut to retrieve header part

pub fn title(&self) -> Result<&str, Utf8Error>

Shortcut to retrieve the location of the title

pub fn cgb_mode(&self) -> CgbMode

Shortcut to retrieve the cgb mode from the header

pub fn size(&self) -> u16

Shortcut to retrieve the rom size from the header

pub fn ram_size(&self) -> u16

Shortcut to retrieve the ram size from the header

pub fn is_sgb(&self) -> bool

Shortcut to retrieve if the rom supports sgb from the header

pub fn cartridge_type(&self) -> CartridgeType

Shortcut to retrieve the cartridge type from the header

pub fn is_jp(&self) -> bool

Shortcut to retrieve if the cartridge is japanese from the header

pub fn version(&self) -> u8

Shortcut to retrieve the version from the header

pub fn verify_header_checksum(&self) -> bool

Verify the checksum from the header

pub fn licensee(&self) -> Licensee

Shortcut to retrieve the licensee from the header